/*
 * Copyright (c) 2008 Nokia Corporation
 * Contact: integration@maemo.org
 *
 * Authors: Hallyson Melo <hallyson.melo@indt.org.br>
 *          Kyller Gorgonio <kyllercg@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */

#ifndef NM_USB_UTILS_H
#define NM_USB_UTILS_H

#include <glib.h>

gboolean nm_usb_utils_is_loaded (void);
gboolean nm_usb_utils_load (const gchar *);
gboolean nm_usb_utils_unload (void);
gboolean nm_usb_utils_put_in_host_mode (void);
gboolean nm_usb_utils_is_host_mode (void);
gboolean nm_usb_utils_put_in_otg_mode (void);
gboolean nm_usb_utils_put_in_charging_only_mode (void);
gboolean nm_usb_utils_is_charging_only (void);

#endif
